==================================================
 In-memory Transport - ``kombu.transport.memory``
==================================================

.. currentmodule:: kombu.transport.memory

.. automodule:: kombu.transport.memory

    .. contents::
        :local:

    Transport
    ---------

    .. autoclass:: Transport
        :members:
        :undoc-members:

    Channel
    -------

    .. autoclass:: Channel
        :members:
        :undoc-members:
